@@ -1,7 +1,7 @@
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
 
-BEGIN { $| = 1; print "1..6\n"; }
+BEGIN { $| = 1; print "1..7\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Lingua::Wordnet;
 $loaded = 1;
@@ -43,6 +43,9 @@ else                                  { print "not ok 5\n"; }
 if ($wn->morph("bluest","a") eq "blue") { print "ok 6\n"; }
 else                                { print "not ok 6\n"; }
 
+if ($synset =~ /baseball/) { print "ok 7\n"; }
+else                        { print "not ok 7\n"; }                                 
+
 $wn->close();
 
 
